var _ref = <b></b>;

var _ref2 = <span></span>;

function render() {
  var children = _ref;

  if (someCondition) {
    children = _ref2;
  }

  return <div>{children}</div>;
}
